package com.me.pacman.level;

import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.me.pacman.PacDude;

public class Level {

    private PacDude game;

    private TextureRegion pellet;
    private TextureRegion powerPellet;

    // Grid of tiles, [rows][columns]
    public LevelTile[][] tiles;


    public Level(PacDude game, String level) {
        this.game = game;

        pellet = game.assets.level[0][6];
        powerPellet = game.assets.level[0][7];

        LevelLoader loader = new LevelLoader(level);
        tiles = loader.loadLevel();
    }

    public LevelTile getTile(int x, int y) {
        return tiles[y][x];
    }

    public LevelTile getTile(float x, float y) {
        return getTile((int) x, (int) y);
    }

    public void setTile(int x, int y, LevelTile tile) {
        tiles[y][x] = tile;
    }

    public void setTile(float x, float y, LevelTile tile) {
        setTile((int) x, (int) y, tile);
    }

    public int getTileCount(LevelTile tile) {
        int count = 0;
        for (int i = 0; i < tiles.length; i++) {
            LevelTile[] row = tiles[i];
            for (int j = 0; j < row.length; j++) {
                if (row[j] == tile) {
                    count++;
                }
            }
        }
        return count;
    }

    public void render(int offsetX, int offsetY) {
        for (int i = 0; i < tiles.length; i++) {
            LevelTile[] row = tiles[i];
            for (int j = 0; j < row.length; j++) {
                LevelTile component = row[j];
                TextureRegion sprite;
                switch (component) {
                    case PELLET:
                        sprite = pellet;
                        break;
                    case POWER_PELLET:
                        sprite = powerPellet;
                        break;
                    default:
                        continue;
                }
                game.batch.draw(sprite, (j * 8) + offsetX, (i * 8) + offsetY);
            }
        }
    }

}
